@@ -1,7 +1,12 @@
 //! The macros lib of Savlo web server framework.
-//! Read more: https://salvo.rs
+//! Read more: <https://salvo.rs>
 #![doc(html_favicon_url = "https://salvo.rs/images/favicon-32x32.png")]
 #![doc(html_logo_url = "https://salvo.rs/images/logo.svg")]
+#![cfg_attr(docsrs, feature(doc_cfg))]
+#![deny(private_in_public, unreachable_pub)]
+#![forbid(unsafe_code)]
+#![warn(missing_docs)]
+
 extern crate proc_macro;
 use proc_macro::TokenStream;
 use proc_macro2::Span;
